==> jc-1.4.0.tar.gz: java/net/URISyntaxException.h <==
// public class java.net.URISyntaxException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 5fae3620c652d2c5 java_net_URISyntaxException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_net_URISyntaxException_H_
#define _JC_java_net_URISyntaxException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URISyntaxException$sub_refs	_jc_java_net_URISyntaxException$sub_refs;
typedef struct _jc_java_net_URISyntaxException$sub_nonrefs	_jc_java_net_URISyntaxException$sub_nonrefs;
typedef struct _jc_java_net_URISyntaxException$refs	_jc_java_net_URISyntaxException$refs;
typedef struct _jc_java_net_URISyntaxException$nonrefs	_jc_java_net_URISyntaxException$nonrefs;
typedef struct _jc_java_net_URISyntaxException$object	_jc_java_net_URISyntaxException$object;

typedef struct _jc_java_net_URISyntaxException$fields_struct	_jc_java_net_URISyntaxException$fields_struct;
typedef const struct _jc_java_net_URISyntaxException$vmethods	_jc_java_net_URISyntaxException$vmethods;
typedef const struct _jc_java_net_URISyntaxException$vtable	_jc_java_net_URISyntaxException$vtable;
typedef const struct _jc_java_net_URISyntaxException$vtype	_jc_java_net_URISyntaxException$vtype;

// Class fields structure
struct _jc_java_net_URISyntaxException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_URISyntaxException$fields_struct _jc_java_net_URISyntaxException$class_fields;

// Constructors
extern void _jc_java_net_URISyntaxException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_net_URISyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_net_URISyntaxException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_net_URISyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jint _jc_java_net_URISyntaxException$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getInput$3b6ee23b9390cffe(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getReason$8fac9a38220a530b(_jc_env *, struct _jc_java_net_URISyntaxException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URISyntaxException$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getInput$3b6ee23b9390cffe;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getReason$8fac9a38220a530b;

// Virtual methods structure
struct _jc_java_net_URISyntaxException$vmethods {
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
	struct _jc_java_lang_String$object	*(*getInput$3b6ee23b9390cffe)(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
	struct _jc_java_lang_String$object	*(*getReason$8fac9a38220a530b)(_jc_env *, struct _jc_java_net_URISyntaxException$object *);
};

// Vtable
struct _jc_java_net_URISyntaxException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_net_URISyntaxException$vmethods	java_net_URISyntaxException;
};

// Vtype
struct _jc_java_net_URISyntaxException$vtype {
	_jc_type			type;
	_jc_java_net_URISyntaxException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URISyntaxException$sub_refs {
	struct _jc_java_lang_String$object	*input;
};

// Reference instance fields (object)
struct _jc_java_net_URISyntaxException$refs {
    _jc_java_net_URISyntaxException$sub_refs	java_net_URISyntaxException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URISyntaxException$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_net_URISyntaxException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_net_URISyntaxException$sub_nonrefs	java_net_URISyntaxException;
};

// Object instance structure
struct _jc_java_net_URISyntaxException$object {
	_jc_java_net_URISyntaxException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URISyntaxException$vtype	*vtype;
	_jc_java_net_URISyntaxException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URISyntaxException$vtype _jc_java_net_URISyntaxException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URISyntaxException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URISyntaxException$class_object;

#endif	/* _JC_java_net_URISyntaxException_H_ */

==> jc-1.4.6.tar.gz: java/net/URISyntaxException.h <==
// public class java.net.URISyntaxException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 5fae3620c652d2c5 java_net_URISyntaxException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_net_URISyntaxException_H_
#define _JC_java_net_URISyntaxException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_URISyntaxException$sub_refs	_jc_java_net_URISyntaxException$sub_refs;
typedef struct _jc_java_net_URISyntaxException$sub_nonrefs	_jc_java_net_URISyntaxException$sub_nonrefs;
typedef struct _jc_java_net_URISyntaxException$refs	_jc_java_net_URISyntaxException$refs;
typedef struct _jc_java_net_URISyntaxException$nonrefs	_jc_java_net_URISyntaxException$nonrefs;
typedef struct _jc_java_net_URISyntaxException$object	_jc_java_net_URISyntaxException$object;

typedef struct _jc_java_net_URISyntaxException$fields_struct	_jc_java_net_URISyntaxException$fields_struct;
typedef const struct _jc_java_net_URISyntaxException$vmethods	_jc_java_net_URISyntaxException$vmethods;
typedef const struct _jc_java_net_URISyntaxException$vtable	_jc_java_net_URISyntaxException$vtable;
typedef const struct _jc_java_net_URISyntaxException$vtype	_jc_java_net_URISyntaxException$vtype;

// Class fields structure
struct _jc_java_net_URISyntaxException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_URISyntaxException$fields_struct _jc_java_net_URISyntaxException$class_fields;

// Constructors
extern void _jc_java_net_URISyntaxException$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_net_URISyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_URISyntaxException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_net_URISyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_net_URISyntaxException$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getInput$3b6ee23b9390cffe(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_URISyntaxException$method$getReason$8fac9a38220a530b(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URISyntaxException$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getInput$3b6ee23b9390cffe;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_net_URISyntaxException$method_info$getReason$8fac9a38220a530b;

// Virtual methods structure
struct _jc_java_net_URISyntaxException$vmethods {
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getInput$3b6ee23b9390cffe)(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getReason$8fac9a38220a530b)(_jc_env *, struct _jc_java_net_URISyntaxException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URISyntaxException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_net_URISyntaxException$vmethods	java_net_URISyntaxException;
};

// Vtype
struct _jc_java_net_URISyntaxException$vtype {
	_jc_type			type;
	_jc_java_net_URISyntaxException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URISyntaxException$sub_refs {
	struct _jc_java_lang_String$object	*input;
};

// Reference instance fields (object)
struct _jc_java_net_URISyntaxException$refs {
    _jc_java_net_URISyntaxException$sub_refs	java_net_URISyntaxException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URISyntaxException$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_net_URISyntaxException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_net_URISyntaxException$sub_nonrefs	java_net_URISyntaxException;
};

// Object instance structure
struct _jc_java_net_URISyntaxException$object {
	_jc_java_net_URISyntaxException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URISyntaxException$vtype	*vtype;
	_jc_java_net_URISyntaxException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URISyntaxException$vtype _jc_java_net_URISyntaxException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URISyntaxException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URISyntaxException$class_object;

#endif	/* _JC_java_net_URISyntaxException_H_ */
